@@ -16,8 +16,8 @@ running Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 64481 2010-06-03 21:18:30Z CJP $"
-__revision__ = "$Revision: 64481 $"
+__svnid__ = "$Id: Editra.py 66186 2010-11-18 04:14:45Z CJP $"
+__revision__ = "$Revision: 66186 $"
 
 #--------------------------------------------------------------------------#
 # Dependencies
@@ -33,7 +33,6 @@ if not hasattr(sys, 'frozen') and 'wx' not in sys.modules:
 
 import base64
 import locale
-import time
 import getopt
 import shutil
 import wx
@@ -66,7 +65,6 @@ import ed_event
 import updater
 import plugin
 import ed_ipc
-import ed_msg
 import ebmlib
 from syntax import synglob
 
@@ -97,6 +95,9 @@ class Editra(wx.App, events.AppEventHandlerMixin):
 
         # Disable debug popups
         wx.Log.EnableLogging(False)
+        # Purge old logs
+        logfile = dev_tool.EdLogFile()
+        logfile.PurgeOldLogs(7)
 
         if ed_glob.SINGLE:
             # Setup the instance checker
@@ -311,7 +312,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
 
         if awin is None:
             awin = self.GetTopWindow()
-            if awin is None or getattr(awin, '__name__', '?') != "MainWindow":
+            if not isinstance(awin, ed_main.MainWindow):
                 if len(self.GetMainWindows()):
                     awin = self.GetMainWindows()[0]
 
@@ -323,12 +324,16 @@ class Editra(wx.App, events.AppEventHandlerMixin):
 
         """
         win = self.GetTopWindow()
-        if getattr(win, '__name__', None) != u"MainWindow":
+        if not isinstance(win, ed_main.MainWindow):
             win = self.GetActiveWindow()
             if win is None:
-                return win
+                return None # UI dead?
 
-        return win.GetNotebook().GetCurrentCtrl()
+        if isinstance(win, ed_main.MainWindow):
+            nbook = win.GetNotebook()
+            if nbook:
+                return nbook.GetCurrentCtrl()
+        return None
 
     def GetMainWindows(self):
         """Returns a list of all open main windows
@@ -911,7 +916,7 @@ def PrintHelp(err=None):
         sys.stderr.write(err + os.linesep)
 
     print(("Editra - %s - Developers Text Editor\n"
-       "Cody Precord (2005-2009)\n\n"
+       "Cody Precord (2005-2010)\n\n"
        "usage: Editra [arguments] [files... ]\n\n"
        "Short Arguments:\n"
        "  -c    Set custom configuration directory at runtime\n"
@@ -928,7 +933,7 @@ def PrintHelp(err=None):
        "  --help            Show this help message\n"
        "  --auth            Print the ipc server info\n"
        "  --version         Print version number and exit\n"
-       "  --profileOut arg  Run Editra in the profier (arg is output file)\n"
+       "  --profileOut arg  Run Editra in the profiler (arg is output file)\n"
       ) % ed_glob.VERSION)
 
     if err is None:
@@ -1110,6 +1115,10 @@ def _Main(opts, args):
     # 3. Start Applications Main Loop
     dev_tool.DEBUGP("[main][info] Starting MainLoop...")
     wx.CallAfter(frame.Raise)
+
+    # Install handlers to exit app if os is shutting down/restarting
+    ebmlib.InstallTermHandler(editra_app.Exit, force=True)
+
     editra_app.MainLoop()
     dev_tool.DEBUGP("[main][info] MainLoop finished exiting application")
     os._exit(0)
