@@ -16,13 +16,14 @@ deduct the requested information.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: pycomp.py 62658 2009-11-15 04:54:55Z CJP $"
-__revision__ = "$Revision: 62658 $"
+__cvsid__ = "$Id: pycomp.py 66256 2010-11-24 17:12:01Z CJP $"
+__revision__ = "$Revision: 66256 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
 import os
 import sys
+import time
 import tokenize
 import types
 from token import NAME, DEDENT, STRING
@@ -30,10 +31,6 @@ from token import NAME, DEDENT, STRING
 import wx
 from wx.py import introspect
 
-# It would be nice to use cStringIO here for the better performance but it
-# doesn't work as uniformly across platfrom as the plain StringIO module. On
-# Linux and python2.4 under all platforms the cStringIO module makes tokens out
-# of each character instead of each actual token which causes the parse to fail.
 from StringIO import StringIO
 
 # Local imports
@@ -44,11 +41,11 @@ import completer
 class Completer(completer.BaseCompleter):
     """Code completer provider"""
     def __init__(self, stc_buffer):
-        """Initiliazes the completer
+        """Initializes the completer
         @param stc_buffer: buffer that contains code
 
         """
-        completer.BaseCompleter.__init__(self, stc_buffer)
+        super(Completer, self).__init__(stc_buffer)
 
         # Setup
         self.SetAutoCompKeys([ord('.'), ])
@@ -85,10 +82,13 @@ class Completer(completer.BaseCompleter):
             # chance of getting the proper completions
             fname = self._buffer.GetFileName()
             if fname:
-                sys.path.insert(0, os.path.dirname(fname))
+                fpath = os.path.dirname(fname)
+                sys.path.insert(0, fpath)
 
+            t1 = time.time()
             cmpl.evalsource(self._buffer.GetText(),
                             self._buffer.GetCurrentLine())
+            dbg("[pycomp][info] Completion eval time: %f" % (time.time() - t1))
 
             if fname:
                 sys.path.pop(0)
@@ -99,29 +99,32 @@ class Completer(completer.BaseCompleter):
                 # Get Auto-completion List
                 complst = cmpl.get_completions(command)
                 sigs = list()
+                type = completer.TYPE_UNKNOWN
                 for sig in complst:
                     word = sig['word'].rstrip(u'(.')
                     if sig['type'] == "function":
-                        word += u'?%d' % completer.IMG_FUNCTION
+                        type = completer.TYPE_FUNCTION
                     elif sig['type'] == "method":
-                        word += u'?%d' % completer.IMG_METHOD
+                        type = completer.TYPE_METHOD
                     elif sig['type'] == "class":
-                        word += u'?%d' % completer.IMG_CLASS
+                        type = completer.TYPE_CLASS
                     elif sig['type'] == "attribute":
-                        word += u'?%d' % completer.IMG_ATTRIBUTE
+                        type = completer.TYPE_ATTRIBUTE
                     elif sig['type'] == "property":
-                        word += u'?%d' % completer.IMG_PROPERTY
+                        type = completer.TYPE_PROPERTY
+                    
+                    sigs.append(completer.Symbol(word, type))
 
-                    sigs.append(word)
-
-#                sigs = [ sig['word'].rstrip('(.') for sig in complst ]
-                sigs.sort(lambda x, y: cmp(x.upper(), y.upper()))
+                sigs.sort(key=lambda x: x.Name.upper())
                 return sigs
 
-        except Exception, msg:
+        except BaseException, msg:
             self._log("[pycomp][err] _GetCompletionInfo: %s, %s" % \
                       (sys.exc_info()[0], sys.exc_info()[1]))
-            return ''
+            if calltip:
+                return u""
+            else:
+                return list()
         
     def GetAutoCompList(self, command):
         """Returns the list of possible completions for a 
@@ -143,7 +146,7 @@ class Completer(completer.BaseCompleter):
         alltext = self._GetCompletionInfo(command, calltip=True)
        
         # split the text into natural paragraphs (a blank line separated)
-        paratext = alltext.split("\n\n")
+        paratext = alltext.split(u"\n\n")
        
         # add text by paragraph until text limit or all paragraphs
         textlimit = 800
@@ -153,15 +156,15 @@ class Completer(completer.BaseCompleter):
             ii = 1
             while ii < numpara and \
                   (len(calltiptext) + len(paratext[ii])) < textlimit:
-                calltiptext = calltiptext + "\n\n" + paratext[ii]
+                calltiptext = calltiptext + u"\n\n" + paratext[ii]
                 ii = ii + 1
 
             # if not all texts are added, add "[...]"
             if ii < numpara:
-                calltiptext = calltiptext + "\n[...]"
+                calltiptext = calltiptext + u"\n[...]"
         # present the function signature only (first newline)
         else:
-            calltiptext = alltext.split("\n")[0]
+            calltiptext = alltext.split(u"\n")[0]
            
         return calltiptext
 
@@ -287,6 +290,7 @@ class PyCompleter(object):
                         tip = u""
                     return tip
                 else:
+                    # Alternate calltip code
                     result = eval(_sanitize(stmt[:-1]), self.compldict)
                     doc = max(getattr(result, '__doc__', ''), ' ')
                     return [{'word' : _cleanstr(self.get_arguments(result)), 
@@ -367,7 +371,9 @@ class PyCompleter(object):
             return completions
         except Exception, msg:
             dbg("[pycomp][err] get_completions: %s [stmt='%s']" % (msg, stmt))
-            return []
+            if ctip:
+                return u""
+            return list()
 
 #-----------------------------------------------------------------------------#
 # Code objects
@@ -380,9 +386,11 @@ class Scope(object):
         @param indent: the indentation/level of this scope
 
         """
-        self.subscopes = []
-        self.docstr = ''
-        self.locals = []
+        super(Scope, self).__init__()
+
+        self.subscopes = list()
+        self.docstr = u''
+        self.locals = list()
         self.parent = None
         self.name = name
         self.indent = indent
@@ -431,8 +439,8 @@ class Scope(object):
         return Scope(self.name, indent)
 
     def _checkexisting(self, test):
-        """Convienance function... keep out duplicates
-        @param test: assignment statement to check for existance of
+        """Convenience function... keep out duplicates
+        @param test: assignment statement to check for existence of
                      variable in the scopes locals
 
         """
@@ -448,20 +456,24 @@ class Scope(object):
 
         """
         cstr = '"""' + self.docstr + '"""\n'
+        nonimport = list()
         for loc in self.locals:
             if loc.startswith('import') or loc.startswith('from'):
-                cstr += loc + '\n'
+                cstr += ("try:\n    %s\nexcept ImportError:\n    pass\n" % loc)
+            else:
+                nonimport.append(loc)
 
         # we need to start with this, to fix up broken completions
         # hopefully this name is unique enough...
         cstr += 'class _PyCmplNoType:\n    def __getattr__(self,name):\n        return None\n'
 
+        # Get all subscopes (classes, functions, methods)
         for sub in self.subscopes:
             cstr += sub.get_code()
 
-        for loc in self.locals:
-            if not loc.startswith('import'):
-                cstr += loc + '\n'
+        # Get remaining local variables
+        for loc in nonimport:
+            cstr += loc + '\n'
 
         return cstr
 
@@ -500,7 +512,7 @@ class Class(Scope):
         @param indent: scope of indentation
 
         """
-        Scope.__init__(self, name, indent)
+        super(Class, self).__init__(name, indent)
         self.supers = supers
 
     def copy_decl(self, indent=0):
@@ -545,7 +557,7 @@ class Function(Scope):
         @param indent: indentation level of functions declaration (scope)
 
         """
-        Scope.__init__(self, name, indent)
+        super(Function, self).__init__(name, indent)
         self.params = params
 
     def copy_decl(self, indent=0):
@@ -571,10 +583,12 @@ class Function(Scope):
 #-----------------------------------------------------------------------------#
 # Main Parser
 
-class PyParser:
+class PyParser(object):
     """Python parsing class"""
     def __init__(self):
         """Initialize and create the PyParser"""
+        super(PyParser, self).__init__()
+
         # Attributes
         self.top = Scope('global', 0)
         self.scope = self.top
@@ -587,8 +601,8 @@ class PyParser:
         @return: tuple of (dottedname, nexttoken)
 
         """
-        name = []
-        if pre == None:
+        name = list()
+        if pre is None:
             tokentype, token = self.next()[:2]
             if tokentype != NAME and token != '*':
                 return ('', token)
@@ -642,8 +656,14 @@ class PyParser:
         while True:
             token = self.next()[1]
             if token in (')', ',') and level == 1:
+                # Remove keyword assignments as they can
+                # cause eval breakage when using undefined
+                # vars.
+                if '=' in name:
+                    name = name.split('=')[0].strip()
                 names.append(name)
                 name = ''
+
             if token == '(':
                 level += 1
             elif token == ')':
@@ -701,10 +721,6 @@ class PyParser:
 
         return Class(cname, super_cls, indent)
 
-    # TODO this returns invalid tokens for some assignment statements.
-    #      In order to avoid this from breaking the eval the statements
-    #      are currently compiled to check syntax and filter accordingly. 
-    #      Need to find why the parse is failing on valid code sometimes.
     def _parseassignment(self):
         """Parse a variable assignment to resolve the variables type
         for introspection.
@@ -732,7 +748,7 @@ class PyParser:
                    # String
                    tokenize.STRING : '""', 'str' : '""',
                    'repr' : '""', 'chr' : '""', 'unichr' : '""',
-                   'hex' : '""', 'oct' : '""',
+                   'hex' : '""', 'oct' : '""', "'" : '""', '"' : '""',
                    # Type
                    'type' : 'type(_PyCmplNoType)',
                    # Tuple
@@ -748,10 +764,8 @@ class PyParser:
             # NOTE: This part of the parse is where the problem is happening
             assign += token
             level = 0
-#            tstack = list()
             while True:
                 tokentype, token = self.next()[:-1]
-#                tstack.append((assign, token, level))
                 if token in ('(', '{', '['):
                     level = level + 1
                 elif token in (']', '}', ')'):
@@ -760,26 +774,40 @@ class PyParser:
                         break
                 elif level == 0:
                     # end of line
-                    if token in (';', '\n'):
+                    if token in (';', '\n', '='):
                         break
-                    elif token == ',':
-                        assign = ''
+                    elif token in ('+', '*'):
+                        # Attempt simple type deduction based on 
+                        # operator statement.
+                        if assign.endswith('"') or assign.endswith("'"):
+                            assign = '""'
+                        else:
+                            assign = '0'
+                        break
+                    elif token in ('/', '-'):
+                        # assignment most likely returns an digit type
+                        # this is the best guess we can make
+                        assign = '0'
+                        break
+                    elif token in ('and', 'or', 'in', '==',
+                                   '<', '>', '!=', 'not', '>=', '<='):
+                        # right side of assignment likely evaluates to bool
+                        assign = 'bool'
+                        break
+#                    elif token == ',':
+#                        assign = ''
                     else:
-                        assign += token
+                        if token == '.' or assign.endswith('.'):
+                            assign += token
+                        else:
+                            assign += (" %s" % token)
 
         # Check syntax to filter out bad tokens
-        # NOTE: temporary till parser is improved more
         try:
             compile(assign, '_pycomp', 'eval')
         except:
-#            print ""
-#            for t in tstack:
-#                print t
-#            print assign
-#            print ""
-#            print ""
             dbg("[pycomp][err] parseassignment bad token: %s" % assign)
-            return None
+            return '_PyCmplNoType()'
         else:
             return assign
 
@@ -804,7 +832,7 @@ class PyParser:
             if type(scp) == Function:
                 cut = 0
 
-                #Handle 'self' params
+                # Handle 'self' params
                 if scp.parent != None and type(scp.parent) == Class:
                     cut = 1
                     params = scp.params[0]
@@ -898,9 +926,9 @@ class PyParser:
                         stmt = self._parseassignment()
                         dbg("[pycomp] parseassignment: %s = %s" % (name, stmt))
                         if stmt != None:
-                            # XXX Safety Check don't allow assigments to 
+                            # XXX Safety Check don't allow assignments to 
                             # item attributes unless the attribute is self
-                            if u'.' not in name or name.startswith(u'self'):
+                            if u'.' not in name or name.startswith('self.'):
                                 self.scope.local("%s = %s" % (name, stmt))
                     freshscope = False
         except StopIteration: #thrown on EOF
