@@ -7,13 +7,13 @@
 ###############################################################################
 
 """
-Editra Buisness Model Library:
+Editra Business Model Library:
 
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: __init__.py 60840 2009-05-31 16:00:50Z CJP $"
-__revision__ = "$Revision: 60840 $"
+__cvsid__ = "$Id: __init__.py 66162 2010-11-15 21:27:37Z CJP $"
+__revision__ = "$Revision: 66162 $"
 
 #-----------------------------------------------------------------------------#
 
@@ -22,12 +22,21 @@ from searcheng import *
 from fchecker import *
 from fileutil import *
 from fileimpl import *
+from txtutil import *
+from logfile import *
 
 from backupmgr import *
+from calllock import *
 
 # Storage Classes
 from histcache import *
 from clipboard import *
 
+# Networking utilities
+from e_weblib import *
+
 # Misc
 from miscutil import *
+from cmenumgr import *
+from osutil import *
+
