@@ -44,8 +44,8 @@ that require a sandwich like layout.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ctrlbox.py 65202 2010-08-06 15:49:23Z CJP $"
-__revision__ = "$Revision: 65202 $"
+__svnid__ = "$Id: ctrlbox.py 66020 2010-11-05 15:43:46Z CJP $"
+__revision__ = "$Revision: 66020 $"
 
 __all__ = ["ControlBox", "CTRLBOX_NAME_STR",
 
@@ -515,8 +515,12 @@ class ControlBar(wx.PyPanel):
 
         """
         sizer = self.GetSizer()
-        sizer.GetItem(0).SetSpacer((top, top))
-        sizer.GetItem(2).SetSpacer((bottom, bottom))
+        if wx.VERSION < (2, 9, 0, 0, ''):
+            sizer.GetItem(0).SetSpacer((top, top))
+            sizer.GetItem(2).SetSpacer((bottom, bottom))
+        else:
+            sizer.GetItem(0).AssignSpacer((top, top))
+            sizer.GetItem(2).AssignSpacer((bottom, bottom))
         sizer.Layout()
 
     def SetWindowStyle(self, style):
