@@ -61,8 +61,8 @@ Requirements:
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: outbuff.py 63558 2010-02-26 01:13:41Z CJP $"
-__revision__ = "$Revision: 63558 $"
+__svnid__ = "$Id: outbuff.py 66333 2010-12-05 19:44:55Z CJP $"
+__revision__ = "$Revision: 66333 $"
 
 __all__ = ["OutputBuffer", "OutputBufferEvent", "ProcessBufferMixin",
            "ProcessThread", "TaskThread", "OPB_STYLE_DEFAULT", "OPB_STYLE_INFO",
@@ -151,7 +151,7 @@ class OutputBufferEvent(wx.PyCommandEvent):
     """Event for data transfer and signaling actions in the L{OutputBuffer}"""
     def __init__(self, etype, eid=wx.ID_ANY, value=''):
         """Creates the event object"""
-        wx.PyCommandEvent.__init__(self, etype, eid)
+        super(OutputBufferEvent, self).__init__(etype, eid)
 
         # Attributes
         self._value = value
@@ -196,7 +196,8 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
                  size=wx.DefaultSize,
                  style=wx.BORDER_SUNKEN,
                  name=OUTPUTBUFF_NAME_STR):
-        wx.stc.StyledTextCtrl.__init__(self, parent, id, pos, size, style, name)
+        super(OutputBuffer, self).__init__(parent, id, pos,
+                                           size, style, name)
 
         # Attributes
         self._mutex = threading.Lock()
@@ -309,7 +310,7 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
     def AppendUpdate(self, value):
         """Buffer output before adding to window. This method can safely be
         called from non gui threads to add updates to the buffer, that will
-        be displayed durning the next idle period.
+        be displayed during the next idle period.
         @param value: update string to append to stack
 
         """
@@ -362,7 +363,7 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
     def DoUpdatesEmpty(self):
         """Called when update stack is empty
         Override this function to perform actions when there are no updates
-        to process. It can be used for things such as temporarly stopping
+        to process. It can be used for things such as temporarily stopping
         the timer or performing idle processing.
 
         """
@@ -605,7 +606,7 @@ class ProcessBufferMixin:
         """Override this method to do an filtering on input that is sent to
         the buffer from the process text. The return text is what is put in
         the buffer.
-        @param txt: incoming udpate text
+        @param txt: incoming update text
         @return: string
 
         """
@@ -632,7 +633,7 @@ class ProcessBufferMixin:
         self.Stop()
 
     def DoProcessStart(self, cmd=''):
-        """Override this method to do any pre processing before starting
+        """Override this method to do any pre-processing before starting
         a processes output.
         @keyword cmd: Command used to start program
         @return: None
@@ -678,7 +679,7 @@ class ProcessThread(threading.Thread):
                             program or run directly
 
         """
-        threading.Thread.__init__(self)
+        super(ProcessThread, self).__init__()
 
         if isinstance(args, list):
             args = u' '.join([arg.strip() for arg in args])
@@ -832,13 +833,38 @@ class ProcessThread(threading.Thread):
                                                        self._cmd['file'],
                                                        self._cmd['args']]])
         command = command.strip()
+        # TODO: exception handling and notification to main thread
+        #       when encoding fails.
+        command = command.encode(sys.getfilesystemencoding())
         if not self._use_shell and not subprocess.mswindows:
-            # shlex does not support unicode
-            command = shlex.split(command.encode(sys.getfilesystemencoding()))
+            # Note: shlex does not support Unicode
+            command = shlex.split(command)
 
-        if sys.platform.lower().startswith('win'):            
+        # TODO: if a file path to the exe has any spaces in it on Windows
+        #       and use_shell is True then the command will fail. Must force
+        #       to False under this condition.
+        use_shell = self._use_shell and not subprocess.mswindows
+        # TODO: See about supporting use_shell on Windows it causes lots of
+        #       issues with gui apps and killing processes when it is True.
+        if use_shell and subprocess.mswindows:
+            # Don't set this flag if we are not using the shell on
+            # Windows as it will cause any gui app to not show on the
+            # display!
             suinfo = subprocess.STARTUPINFO()
-            suinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
+            #TODO: move this into common library as it is needed
+            #      by most code that uses subprocess
+            if sys.platform.lower().startswith('win'):            
+                if hasattr(subprocess, 'STARTF_USESHOWWINDOW'):
+                    suinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
+                else:
+                    try:
+                        from win32process import STARTF_USESHOWWINDOW
+                        suinfo.dwFlags |= STARTF_USESHOWWINDOW
+                    except ImportError:
+                        # Give up and try hard coded value from Windows.h
+                        suinfo.dwFlags |= 0x00000001
+            else:
+                suinfo = None
         else:
             suinfo = None
         
@@ -847,7 +873,7 @@ class ProcessThread(threading.Thread):
             self._proc = subprocess.Popen(command,
                                           stdout=subprocess.PIPE,
                                           stderr=subprocess.STDOUT,
-                                          shell=self._use_shell,
+                                          shell=use_shell,
                                           cwd=self._cwd,
                                           env=self._env,
                                           startupinfo=suinfo)
@@ -916,7 +942,7 @@ class ProcessThread(threading.Thread):
 
     def SetFilename(self, fname):
         """Set the filename to run the command on
-        @param fname: string or unicode
+        @param fname: string or Unicode
 
         """
         self._cmd['file'] = fname
@@ -929,12 +955,12 @@ class TaskThread(threading.Thread):
         """Initialize the TaskThread. All *args and **kwargs are passed
         to the task.
 
-        @param parent: Parent Window/EventHandler to recieve the events
+        @param parent: Parent Window/EventHandler to receive the events
                        generated by the process.
         @param task: callable should be a generator object and must be iterable
 
         """
-        threading.Thread.__init__(self)
+        super(TaskThread, self).__init__()
 
         # Attributes
         self.cancel = False         # Abort task
@@ -945,7 +971,7 @@ class TaskThread(threading.Thread):
 
     def run(self):
         """Start running the task"""
-        # Notify that task is begining
+        # Notify that task is beginning
         evt = OutputBufferEvent(edEVT_TASK_START, self._parent.GetId())
         wx.PostEvent(self._parent, evt)
         time.sleep(.5) # Give the event a chance to be processed
