@@ -15,14 +15,13 @@ syntax highlighting of all supported filetypes.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_basestc.py 64558 2010-06-11 11:53:43Z CJP $"
-__revision__ = "$Revision: 64558 $"
+__svnid__ = "$Id: ed_basestc.py 66083 2010-11-10 00:50:37Z CJP $"
+__revision__ = "$Revision: 66083 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
 import wx
 import wx.stc
-import types
 
 # Editra Imports
 import ed_glob
@@ -114,12 +113,28 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
     #---- Public Methods ----#
 
-    def AddBookmark(self):
-        """Add a bookmark and return its handle"""
-        cline = self.GetCurrentLine()
-        return self.MarkerAdd(cline, MARK_MARGIN)
+    def AddBookmark(self, line=-1):
+        """Add a bookmark and return its handle
+        @keyword line: if < 0 bookmark will be added to current line
+
+        """
+        if line < 0:
+            line = self.GetCurrentLine()
+        return self.MarkerAdd(line, MARK_MARGIN)
+
+    def RemoveBookmark(self, line):
+        """Remove the book mark from the given line
+        @param line: int
+
+        """
+        self.MarkerDelete(line, MARK_MARGIN)
+
+    def RemoveAllBookmarks(self):
+        """Remove all the bookmarks in the buffer"""
+        self.MarkerDeleteAll(MARK_MARGIN)
 
     def AddLine(self, before=False, indent=False):
+
         """Add a new line to the document
         @keyword before: whether to add the line before current pos or not
         @keyword indent: autoindent the new line
@@ -466,6 +481,7 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
     @property
     def File(self):
+        """Reference to this buffers file object"""
         return self.file
 
     def FindLexer(self, set_ext=u''):
@@ -508,17 +524,20 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.OnChanged(wx.stc.StyledTextEvent(wx.stc.wxEVT_STC_CHANGE,
                                               self.GetId()))
 
-    def GetCommandStr(self):
+    def GetCommandStr(self, line=None, col=None):
         """Gets the command string to the left of the autocomp
         activation character.
+        @keyword line: optional if None current cursor position used
+        @keyword col: optional if None current cursor position used
         @return: the command string to the left of the autocomp char
         @todo: fillups are currently disabled. See note in Configure.
 
         """
-        # NOTE: the column position returned by GetCurLine is not correct
-        #       for multibyte characters.
-        line, col = self.GetCurLine()
-        col = self.GetColumn(self.GetCurrentPos())
+        if None in (line, col):
+            # NOTE: the column position returned by GetCurLine is not correct
+            #       for multibyte characters.
+            line, col = self.GetCurLine()
+            col = self.GetColumn(self.GetCurrentPos())
         cmd_lmt = list(self._code['compsvc'].GetAutoCompStops() + \
                        self._code['compsvc'].GetAutoCompFillups())
         for key in self._code['compsvc'].GetAutoCompKeys():
@@ -669,6 +688,16 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             bMulti = sline != eline
         return bMulti
 
+    def CallTipShow(self, position, tip):
+        """Show a calltip at the given position in the control
+        @param position: int
+        @param tip: unicode
+
+        """
+        if self.CallTipActive():
+            self.CallTipCancel()
+        super(EditraBaseStc, self).CallTipShow(position, tip)
+
     def HidePopups(self):
         """Hide autocomp/calltip popup windows if any are active"""
         if self.AutoCompActive():
