@@ -14,8 +14,8 @@ access point for all common variables in the project.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_glob.py 63532 2010-02-21 21:45:16Z CJP $"
-__revision__ = "$Revision: 63532 $"
+__svnid__ = "$Id: ed_glob.py 66160 2010-11-15 02:25:56Z CJP $"
+__revision__ = "$Revision: 66160 $"
 
 __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN',
             'ID_CLOSE', 'ID_CLOSEALL', 'ID_SAVE', 'ID_SAVEAS', 'ID_SAVEALL',
@@ -66,6 +66,7 @@ import wxcompat
 #---- Configuration Locations ----#
 # Values set when main loads
 CONFIG = {
+          'ISLOCAL'     : False, # Using local config (no abs path)
           'CONFIG_BASE' : None, # Set if config base is in nonstandard location
           'INSTALL_DIR' : "",   # Instal directory
           'CONFIG_DIR'  : "",   # Root configration directory
@@ -177,6 +178,7 @@ ID_PRINT_MODE    = wx.NewId()
 ID_TRANSPARENCY  = wx.NewId()
 ID_PREF_SPOS     = wx.NewId()
 ID_PREF_UPDATE_BAR = wx.NewId()
+ID_PREF_VIRT_SPACE = wx.NewId()
 ID_PREF_WARN_EOL = wx.NewId()
 ID_SESSION       = wx.NewId()
 
@@ -278,6 +280,7 @@ ID_FORWARD           = wx.ID_FORWARD
 ID_HARDDISK          = wx.NewId()
 ID_KEY_PROFILES      = wx.NewId()
 ID_LOGGER            = wx.NewId()
+ID_BOOKMARK_MGR      = wx.NewId()
 ID_MOVE_TAB          = wx.NewId()
 ID_PACKAGE           = wx.NewId()
 ID_PYSHELL           = wx.NewId()
@@ -366,6 +369,7 @@ ID_2_PROF = {
              ID_PREF_TABW         : 'TABWIDTH',
              ID_VIEW_TOOL         : 'TOOLBAR',
              ID_PREF_TABS         : 'USETABS',
+             ID_PREF_VIRT_SPACE   : 'VIEWVERTSPACE',
              ID_VI_MODE           : 'VI_EMU',
              ID_VI_NORMAL_DEFAULT : 'VI_NORMAL_DEFAULT',
              ID_PREF_WARN_EOL     : 'WARN_EOL',
@@ -385,4 +389,4 @@ def EOLModeMap():
 # Default Plugins
 DEFAULT_PLUGINS = ("generator.Html", "generator.LaTeX", "generator.Rtf",
                    "iface.Shelf", "ed_theme.TangoTheme", "ed_log.EdLogViewer",
-                   "ed_search.EdFindResults")
+                   "ed_search.EdFindResults", "ed_bookmark.EdBookmarks")
