@@ -16,25 +16,22 @@ displaying a L{LogViewer} in the Shelf.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_log.py 54578 2008-07-11 13:37:52Z CJP $"
-__revision__ = "$Revision: 54578 $"
+__svnid__ = "$Id: ed_log.py 66214 2010-11-19 22:43:00Z CJP $"
+__revision__ = "$Revision: 66214 $"
 
 #--------------------------------------------------------------------------#
-# Dependancies
+# Imports
 import os
 import re
 import wx
 
 # Editra Libraries
 import ed_msg
-import eclib.outbuff as outbuff
-import eclib.ctrlbox as ctrlbox
-import eclib.platebtn as platebtn
+import eclib
 import iface
 import plugin
 from profiler import Profile_Get
 import ed_glob
-import ed_txt
 
 #-----------------------------------------------------------------------------#
 # Globals
@@ -47,50 +44,60 @@ SHOW_ALL_MSG = 'ALL'
 class EdLogViewer(plugin.Plugin):
     """Shelf interface implementation for the log viewer"""
     plugin.Implements(iface.ShelfI)
-    ID_LOGGER = wx.NewId()
 
-    @property
-    def __name__(self):
-        return u'Editra Log'
+    __name__ = u'Editra Log'
 
-    def AllowMultiple(self):
+    @staticmethod
+    def AllowMultiple():
         """EdLogger allows multiple instances"""
         return True
 
-    def CreateItem(self, parent):
+    @staticmethod
+    def CreateItem(parent):
         """Returns a log viewr panel"""
         return LogViewer(parent)
 
-    def GetId(self):
-        """Plugin menu identifier ID"""
-        return self.ID_LOGGER
+    def GetBitmap(self):
+        """Get the log viewers tab icon
+        @return: wx.Bitmap
 
-    def GetMenuEntry(self, menu):
+        """
+        bmp = wx.ArtProvider.GetBitmap(str(self.GetId()), wx.ART_MENU)
+        return bmp
+
+    @staticmethod
+    def GetId():
+        """Plugin menu identifier ID"""
+        return ed_glob.ID_LOGGER
+
+    @staticmethod
+    def GetMenuEntry(menu):
         """Get the menu entry for the log viewer
         @param menu: the menu items parent menu
 
         """
-        return wx.MenuItem(menu, self.ID_LOGGER, _("Editra Log"),
+        return wx.MenuItem(menu, ed_glob.ID_LOGGER, _("Editra Log"),
                            _("View Editra's console log"))
 
     def GetName(self):
         """Return the name of this control"""
         return self.__name__
 
-    def IsStockable(self):
+    @staticmethod
+    def IsStockable():
         """EdLogViewer can be saved in the shelf preference stack"""
         return True
 
 #-----------------------------------------------------------------------------#
 
 # LogViewer Ui Implementation
-class LogViewer(ctrlbox.ControlBox):
+class LogViewer(eclib.ControlBox):
     """LogViewer is a control for displaying and working with output
     from Editra's log.
 
     """
     def __init__(self, parent):
-        ctrlbox.ControlBox.__init__(self, parent)
+        eclib.ControlBox.__init__(self, parent)
 
         # Attributes
         self._buffer = LogBuffer(self)
@@ -104,19 +111,20 @@ class LogViewer(ctrlbox.ControlBox):
         self.Bind(wx.EVT_BUTTON,
                   lambda evt: self._buffer.Clear(), id=wx.ID_CLEAR)
         self.Bind(wx.EVT_CHOICE, self.OnChoice, self._srcfilter)
+
+        # Message Handlers
         ed_msg.Subscribe(self.OnThemeChange, ed_msg.EDMSG_THEME_CHANGED)
 
     def __del__(self):
         """Cleanup and unsubscribe from messages"""
         ed_msg.Unsubscribe(self.OnThemeChange)
-        super(LogViewer).__del__()
 
     def __DoLayout(self):
         """Layout the log viewer window"""
         # Setup ControlBar
-        ctrlbar = ctrlbox.ControlBar(self, style=ctrlbox.CTRLBAR_STYLE_GRADIENT)
+        ctrlbar = eclib.ControlBar(self, style=eclib.CTRLBAR_STYLE_GRADIENT)
         if wx.Platform == '__WXGTK__':
-            ctrlbar.SetWindowStyle(ctrlbox.CTRLBAR_STYLE_DEFAULT)
+            ctrlbar.SetWindowStyle(eclib.CTRLBAR_STYLE_DEFAULT)
 
         # View Choice
         self._srcfilter = wx.Choice(ctrlbar, wx.ID_ANY, choices=[])
@@ -129,8 +137,8 @@ class LogViewer(ctrlbox.ControlBox):
         cbmp = wx.ArtProvider.GetBitmap(str(ed_glob.ID_DELETE), wx.ART_MENU)
         if cbmp.IsNull() or not cbmp.IsOk():
             cbmp = None
-        clear = platebtn.PlateButton(ctrlbar, wx.ID_CLEAR, _("Clear"),
-                                     cbmp, style=platebtn.PB_STYLE_NOBG)
+        clear = eclib.PlateButton(ctrlbar, wx.ID_CLEAR, _("Clear"),
+                                     cbmp, style=eclib.PB_STYLE_NOBG)
         ctrlbar.AddControl(clear, wx.ALIGN_RIGHT)
         ctrlbar.SetVMargin(1, 1)
         self.SetControlBar(ctrlbar)
@@ -165,20 +173,22 @@ class LogViewer(ctrlbox.ControlBox):
             self._srcfilter.SetSelection(0)
 
 #-----------------------------------------------------------------------------#
-class LogBuffer(outbuff.OutputBuffer):
+class LogBuffer(eclib.OutputBuffer):
     """Buffer for displaying log messages that are sent on Editra's
     log channel.
+    @todo: make line buffering configurable through interface
 
     """
     RE_WARN_MSG = re.compile(r'\[err\]|\[error\]|\[warn\]')
-    ERROR_STYLE = outbuff.OPB_STYLE_MAX + 1
+    ERROR_STYLE = eclib.OPB_STYLE_MAX + 1
 
     def __init__(self, parent):
-        outbuff.OutputBuffer.__init__(self, parent)
+        eclib.OutputBuffer.__init__(self, parent)
 
         # Attributes
         self._filter = SHOW_ALL_MSG
         self._srcs = list()
+        self.SetLineBuffering(2000)
 
         # Setup
         font = Profile_Get('FONT1', 'font', wx.Font(11, wx.FONTFAMILY_MODERN, 
@@ -206,8 +216,6 @@ class LogBuffer(outbuff.OutputBuffer):
         if src not in self._srcs:
             self._srcs.append(src)
             self.GetParent().SetSources(self._srcs)
-        else:
-            pass
 
     def ApplyStyles(self, start, txt):
         """Apply coloring to error and warning messages
@@ -221,7 +229,9 @@ class LogBuffer(outbuff.OutputBuffer):
             sty_s = start + group.start()
             sty_e = start + group.end()
             self.StartStyling(sty_s, 0xff)
-            self.SetStyling(sty_e - sty_s, self.ERROR_STYLE)
+
+            # Highlight error messages with ERROR_STYLE
+            self.SetStyling(sty_e - sty_s, LogBuffer.ERROR_STYLE)
 
     def SetFilter(self, src):
         """Set the level of what is shown in the display
@@ -243,17 +253,26 @@ class LogBuffer(outbuff.OutputBuffer):
         @param msg: Message Object containing a LogMsg
 
         """
+        if wx.Thread_IsMain():
+            self.DoUpdateLog(msg)
+        else:
+            # Delegate to main thread
+            wx.CallAfter(self.DoUpdateLog, msg)
+
+    def DoUpdateLog(self, msg):
         if not self.IsRunning():
-            if wx.Thread_IsMain():
-                self.Start(150)
+            self.Start(150)
 
         # Check filters
         logmsg = msg.GetData()
-        self.AddFilter(logmsg.Origin)
+        org = logmsg.Origin
+        if org not in self._srcs:
+            self.AddFilter(org)
+
         if self._filter == SHOW_ALL_MSG:
             self.AppendUpdate(unicode(logmsg) + os.linesep)
         elif self._filter == logmsg.Origin:
-            msg = "[%s][%s]%s" % (logmsg.ClockTime, logmsg.Type, logmsg.Value)
+            msg = u"[%s][%s]%s" % (logmsg.ClockTime, logmsg.Type, logmsg.Value)
             self.AppendUpdate(msg + os.linesep)
         else:
             pass
