@@ -15,8 +15,8 @@ main Ui component of the editor that contains all the other components.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 65766 2010-10-05 11:45:44Z CJP $"
-__revision__ = "$Revision: 65766 $"
+__svnid__ = "$Id: ed_main.py 66247 2010-11-23 19:49:55Z CJP $"
+__revision__ = "$Revision: 66247 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -327,6 +327,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         """
         if self._mlock.IsLocked():
             # Deactivated for popup, leave handlers hooked up
+            wx.UpdateUIEvent.SetMode(wx.UPDATE_UI_PROCESS_ALL)
             evt.Skip()
             return
 
@@ -1493,7 +1494,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         # It seems under some cases when running under windows the call to
         # subprocess in webbrowser will fail and raise an exception here. So
-        # simply trap and ingnore it.
+        # simply trap and ignore it.
         try:
             self.PushStatusText(_("Opening %s") % page, SB_INFO)
             webbrowser.open(page, 1)
@@ -1611,12 +1612,20 @@ class MainWindowAddOn(plugin.Plugin):
         handlers = list()
         for observer in self.observers:
             try:
+                items = None
                 if ui_evt:
-                    items = observer.GetUIHandlers()
+                    if hasattr(observer, 'GetUIHandlers'):
+                        items = observer.GetUIHandlers()
+                        assert isinstance(items, list), "Must be a list()!"
                 else:
-                    items = observer.GetMenuHandlers()
+                    if hasattr(observer, 'GetMenuHandlers'):
+                        items = observer.GetMenuHandlers()
+                        assert isinstance(items, list), "Must be a list()!"
             except Exception, msg:
-                util.Log("[ed_main][err] MainWindoAddOn.GetEventHandlers: %s" % str(msg))
+                util.Log("[ed_main][err] MainWindowAddOn.GetEventHandlers: %s" % str(msg))
                 continue
-            handlers.extend(items)
+
+            if items is not None:
+                handlers.extend(items)
+
         return handlers
