@@ -13,8 +13,8 @@ This class implements Editra's main notebook control.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_pages.py 65790 2010-10-10 19:47:11Z CJP $"
-__revision__ = "$Revision: 65790 $"
+__svnid__ = "$Id: ed_pages.py 66247 2010-11-23 19:49:55Z CJP $"
+__revision__ = "$Revision: 66247 $"
 
 #--------------------------------------------------------------------------#
 # Dependencies
@@ -86,7 +86,11 @@ class EdPages(aui.AuiNotebook):
 
         # Setup Tab Navigator
         ed_icon = ed_glob.CONFIG['SYSPIX_DIR'] + u"editra.png"
-        self.SetNavigatorIcon(wx.Bitmap(ed_icon, wx.BITMAP_TYPE_PNG))
+        bmp = wx.Bitmap(ed_icon, wx.BITMAP_TYPE_PNG)
+        if bmp.IsOk():
+            self.SetNavigatorIcon(bmp)
+        else:
+            util.Log("[ed_pages][warn] Bad bitmap: %s" % ed_icon)
 
         # Setup the ImageList and the default image
         imgl = wx.ImageList(16, 16)
@@ -111,6 +115,7 @@ class EdPages(aui.AuiNotebook):
         self.Bind(aui.EVT_AUINOTEBOOK_TAB_MIDDLE_UP, self.OnMClickUp)
         self.Bind(aui.EVT_AUINOTEBOOK_TAB_RIGHT_UP, self.OnTabMenu)
         self.Bind(aui.EVT_AUINOTEBOOK_ALLOW_DND, self.OnAllowDnD)
+        self.Bind(aui.EVT_AUINOTEBOOK_END_DRAG, self.OnDragFinished)
 
         self.Bind(wx.stc.EVT_STC_CHANGE, self.OnUpdatePageText)
         self.Bind(wx.EVT_MENU, self.OnMenu)
@@ -355,7 +360,7 @@ class EdPages(aui.AuiNotebook):
             try:
                 flist = cPickle.load(f_handle)
                 # TODO: Extend in future to support loading sessions
-                #       for mutiple windows.
+                #       for multiple windows.
                 flist = flist.get('win1', list()) 
                 for item in flist:
                     if type(item) not in (unicode, str):
@@ -430,6 +435,10 @@ class EdPages(aui.AuiNotebook):
         if isinstance(dsource, EdPages):
             evt.Allow()
 
+    def OnDragFinished(self, evt):
+        self.UpdateIndexes()
+        evt.Skip()
+
     def OnMenu(self, evt):
         """Handle context menu events
         @param evt: wx.MenuEvent
@@ -527,7 +536,7 @@ class EdPages(aui.AuiNotebook):
                 self.control.SetCaretPos(pos)
         else:
             # Raise page to top and goto position
-            pages = [self.GetPage(page) for page in xrange(self.GetPageCount())]
+            pages = [self.GetPage(page) for page in range(self.GetPageCount())]
             idx = pages.index(ctrl)
             self.ChangePage(idx)
             ctrl.SetCaretPos(pos)
@@ -710,7 +719,7 @@ class EdPages(aui.AuiNotebook):
         # Check if file needs to be opened
         # TODO: these steps could be combined together with some
         #       refactoring of the _NeedOpen method. Requires extra
-        #       testing though to check for dependancies on current
+        #       testing though to check for dependencies on current
         #       behavior.
         if quiet and self.HasFileOpen(path2file):
             self.GotoPage(path2file)
@@ -818,6 +827,12 @@ class EdPages(aui.AuiNotebook):
 
     def DoPostLoad(self):
         """Perform post file open actions"""
+        # Ensure that document buffer is writable after an editable
+        # document is opened in the buffer.
+        doc = self.control.GetDocument()
+        if not doc.IsReadOnly() and not doc.IsRawBytes():
+            self.control.SetReadOnly(False)
+
         # Set last known caret position if the user setting is enabled
         # and the caret position has not been changed during a threaded
         # file loading operation.
