@@ -15,8 +15,8 @@ text documents and files.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_search.py 62512 2009-10-31 00:34:33Z CJP $"
-__revision__ = "$Revision: 62512 $"
+__svnid__ = "$Id: ed_search.py 66158 2010-11-15 02:23:30Z CJP $"
+__revision__ = "$Revision: 66158 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -45,8 +45,8 @@ class EdSearchEngine(ebmlib.SearchEngine):
     """Text searching engine"""
     def __init__(self, query, regex=True, down=True,
                  matchcase=True, wholeword=False):
-        ebmlib.SearchEngine.__init__(self, query, regex, down,
-                                     matchcase, wholeword)
+        super(EdSearchEngine, self).__init__(query, regex, down,
+                                             matchcase, wholeword)
         # Atttributes
         self._offset = 0
 
@@ -95,7 +95,7 @@ class SearchController(object):
         @param getstc: Callable to get the current buffer with
 
         """
-        object.__init__(self)
+        super(SearchController, self).__init__()
 
         # Attributes
         self._parent   = owner
@@ -128,7 +128,7 @@ class SearchController(object):
     def __del__(self):
         """Cleanup message handlers"""
         ed_msg.Unsubscribe(self._OnShowFindMsg)
-        if isinstance(self._finddlg, wx.Window):
+        if self._finddlg:
             self._finddlg.Destroy()
 
     def _CreateNewDialog(self, e_id):
@@ -468,6 +468,13 @@ class SearchController(object):
                      for fname in self._parent.GetTextControls()]
             ed_msg.PostMessage(ed_msg.EDMSG_START_SEARCH,
                                (engine.SearchInFiles, [files,], dict()))
+        elif smode == eclib.LOCATION_IN_CURRENT_DIR:
+            stc = self._stc()
+            path = ebmlib.GetPathName(stc.GetFileName())
+            engine.SetFileFilters(evt.GetFileFilters())
+            ed_msg.PostMessage(ed_msg.EDMSG_START_SEARCH,
+                               (engine.SearchInDirectory,
+                               [path,], dict(recursive=evt.IsRecursive())))
         elif smode == eclib.LOCATION_IN_FILES:
             path = evt.GetDirectory()
             engine.SetFileFilters(evt.GetFileFilters())
@@ -501,9 +508,9 @@ class SearchController(object):
             self._li_sel = self._finddlg.GetLookinSelection()
             self._filters = self._finddlg.GetFileFilters()
 
-            # Store in profile. Only save most recent 5 in history
-            if len(self._li_choices) > 5:
-                choices = self._li_choices[-5:]
+            # Store in profile. Only save most recent 8 in history
+            if len(self._li_choices) > 8:
+                choices = self._li_choices[-8:]
             else:
                 choices = self._li_choices
 
@@ -551,9 +558,13 @@ class SearchController(object):
         self._stc().ReplaceSelection(value)
 
         # Go to the next match
-        # Fake event object for on Find Handler
-        tevt = eclib.FindEvent(eclib.edEVT_FIND_NEXT, ed_glob.ID_FIND_PREVIOUS)
-        self.OnFind(tevt, True)
+        eid = ed_glob.ID_FIND_NEXT
+        if evt.IsUp():
+            eid = ed_glob.ID_FIND_PREVIOUS
+        tevt = eclib.FindEvent(eclib.edEVT_FIND_NEXT, eid)
+        tevt.SetFlags(evt.GetFlags())
+        tevt.SetFindString(evt.GetFindString())
+        self.OnFind(tevt)
 
     def OnReplaceAll(self, evt):
         """Replace all instance of the search string with the given
@@ -601,9 +612,9 @@ class SearchController(object):
                 if matches is not None:
                     self.ReplaceInStc(ctrl, matches, rstring, evt.IsRegEx())
                     results += len(matches)
-        elif smode == eclib.LOCATION_IN_FILES:
+        elif smode in (eclib.LOCATION_IN_CURRENT_DIR, eclib.LOCATION_IN_FILES):
             dlg = wx.MessageDialog(self._parent,
-                                   _("Sorry will be ready for next version"),
+                                   _("Sorry will be ready for future version"),
                                    _("Not implemented"),
 #                                   _("Warning this cannot be undone!"),
 #                                   _("Do Replace All?"),
@@ -773,7 +784,7 @@ class EdSearchCtrl(wx.SearchCtrl):
         @param menulen: max length of history menu
 
         """
-        wx.SearchCtrl.__init__(self, parent, id_, value, pos, size, style)
+        super(EdSearchCtrl, self).__init__(parent, id_, value, pos, size, style)
 
         # Attributes
         self._parent     = parent
@@ -1031,8 +1042,8 @@ class EdSearchCtrl(wx.SearchCtrl):
         tmp = self.GetValue()
         self.ShowCancelButton(len(tmp) > 0)
 
-        # Dont do search for navigation keys
-        if tmp == wx.EmptyString or evt.CmdDown() or \
+        # Don't do search for navigation keys
+        if tmp == wx.EmptyString or evt.CmdDown() or evt.ControlDown() or \
            e_key in [wx.WXK_COMMAND, wx.WXK_LEFT, wx.WXK_RIGHT, wx.WXK_CONTROL,
                      wx.WXK_ALT, wx.WXK_UP, wx.WXK_DOWN, wx.WXK_F1, wx.WXK_F2, 
                      wx.WXK_F3, wx.WXK_F4, wx.WXK_F5, wx.WXK_F6, wx.WXK_F7, 
@@ -1139,7 +1150,7 @@ class EdFindResults(plugin.Plugin):
         return self.__name__
 
     def IsStockable(self):
-        """EdLogViewer can be saved in the shelf preference stack"""
+        """EdFindResults can be saved in the shelf preference stack"""
         return False
 
     @classmethod
@@ -1194,7 +1205,7 @@ class SearchResultScreen(eclib.ControlBox):
         @param parent: parent window
 
         """
-        eclib.ControlBox.__init__(self, parent)
+        super(SearchResultScreen, self).__init__(parent)
 
         # Attributes
         self._meth = None
@@ -1338,7 +1349,7 @@ class SearchResultList(eclib.OutputBuffer):
     STY_SEARCH_MATCH = eclib.OPB_STYLE_MAX + 1
     RE_FIND_MATCH = re.compile('(.+) \(([0-9]+)\)\: .+')
     def __init__(self, parent):
-        eclib.OutputBuffer.__init__(self, parent)
+        super(SearchResultList, self).__init__(parent)
 
         # Attributes
         self._files = 0
