@@ -18,8 +18,8 @@ specific options such as commenting code.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_stc.py 64591 2010-06-15 04:00:50Z CJP $"
-__revision__ = "$Revision: 64591 $"
+__svnid__ = "$Id: ed_stc.py 66336 2010-12-05 22:07:51Z CJP $"
+__revision__ = "$Revision: 66336 $"
 
 #-------------------------------------------------------------------------#
 # Imports
@@ -95,7 +95,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
         @keyword use_dt: whether to use a drop target or not
 
         """
-        ed_basestc.EditraBaseStc.__init__(self, parent, id_, pos, size, style)
+        super(EditraStc, self).__init__(parent, id_, pos, size, style)
 
         self.SetModEventMask(wx.stc.STC_PERFORMED_UNDO | \
                              wx.stc.STC_PERFORMED_REDO | \
@@ -117,6 +117,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
         self.key_handler = KeyHandler(self)
         self._backup_done = True
         self._bktimer = wx.Timer(self)
+        self._dwellsent = False
 
         # Macro Attributes
         self._macro = list()
@@ -135,12 +136,15 @@ class EditraStc(ed_basestc.EditraBaseStc):
         self.UpdateBaseStyles()
 
         # Other Settings
+        self.SetMouseDwellTime(800)
         self.UsePopUp(False)
 
         #self.Bind(wx.stc.EVT_STC_MACRORECORD, self.OnRecordMacro)
         self.Bind(wx.stc.EVT_STC_MARGINCLICK, self.OnMarginClick)
         self.Bind(wx.stc.EVT_STC_UPDATEUI, self.OnUpdateUI)
         self.Bind(wx.stc.EVT_STC_USERLISTSELECTION, self.OnUserListSel)
+        self.Bind(wx.stc.EVT_STC_DWELLSTART, self.OnDwellStart)
+        self.Bind(wx.stc.EVT_STC_DWELLEND, self.OnDwellEnd)
         self.Bind(wx.EVT_KEY_DOWN, self.OnKeyDown)
         self.Bind(wx.EVT_CHAR, self.OnChar)
         self.Bind(wx.EVT_KEY_UP, self.OnKeyUp)
@@ -155,6 +159,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
     __name__ = u"EditraTextCtrl"
 
     #---- Protected Member Functions ----#
+
     def _BuildMacro(self):
         """Constructs a macro script from items in the macro
         record list.
@@ -199,10 +204,13 @@ class EditraStc(ed_basestc.EditraBaseStc):
 
     def _MacHandleKey(self, k_code, shift_down, alt_down, ctrl_down, cmd_down):
         """Handler for mac specific actions"""
+        if alt_down:
+            return False
+
         if (k_code == wx.WXK_BACK and shift_down) and \
-           not (alt_down or ctrl_down or cmd_down):
+           not (ctrl_down or cmd_down):
             self.DeleteForward()
-        elif cmd_down and True not in (alt_down, ctrl_down):
+        elif cmd_down and not ctrl_down:
             line = self.GetCurrentLine()
             if k_code == wx.WXK_RIGHT:
                 pos = self.GetLineStartPosition(line)
@@ -224,6 +232,37 @@ class EditraStc(ed_basestc.EditraBaseStc):
         return True
 
     #---- Public Member Functions ----#
+
+    def AddBookmark(self, line=-1):
+        """Add a bookmark and return its handle
+        Sends notifications for bookmark added
+        @keyword line: if < 0 bookmark will be added to current line
+
+        """
+        rval = super(EditraStc, self).AddBookmark(line)
+        mdata = dict(stc=self, added=True, line=line, handle=rval)
+        ed_msg.PostMessage(ed_msg.EDMSG_UI_STC_BOOKMARK, mdata)
+        return rval
+
+    def RemoveBookmark(self, line):
+        """Remove the book mark from the given line
+        Sends notifications for bookmark removal.
+        @param line: int
+
+        """
+        super(EditraStc, self).RemoveBookmark(line)
+        mdata = dict(stc=self, added=False, line=line)
+        ed_msg.PostMessage(ed_msg.EDMSG_UI_STC_BOOKMARK, mdata)
+
+    def RemoveAllBookmarks(self):
+        """Remove all the bookmarks in the buffer
+        Sends notifications for bookmark removal.
+
+        """
+        super(EditraStc, self).RemoveAllBookmark()
+        mdata = dict(stc=self, added=False, line=-1)
+        ed_msg.PostMessage(ed_msg.EDMSG_UI_STC_BOOKMARK, mdata)
+
     def PlayMacro(self):
         """Send the list of built up macro messages to the editor
         to be played back.
@@ -252,11 +291,11 @@ class EditraStc(ed_basestc.EditraBaseStc):
         mark = -1
         if action == ed_glob.ID_ADD_BM:
             if self.MarkerGet(lnum):
-                self.MarkerDelete(lnum, ed_basestc.MARK_MARGIN)
+                self.RemoveBookmark(lnum)
             else:
-                self.MarkerAdd(lnum, ed_basestc.MARK_MARGIN)
+                self.AddBookmark(lnum)
         elif action == ed_glob.ID_DEL_ALL_BM:
-            self.MarkerDeleteAll(ed_basestc.MARK_MARGIN)
+            self.RemoveAllBookmarks()
         elif action == ed_glob.ID_NEXT_MARK:
             if self.MarkerGet(lnum):
                 lnum += 1
@@ -358,8 +397,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
         self.SetViEmulationMode(_PGET('VI_EMU'), _PGET('VI_NORMAL_DEFAULT'))
         self.SetViewEdgeGuide(_PGET('SHOW_EDGE'))
         self.EnableAutoBackup(_PGET('AUTOBACKUP'))
-        # NOTE: disabled because it is more annoying than it is beneficial.
-#        self.SetEndAtLastLine(False)
+        self.SetEndAtLastLine(not _PGET('VIEWVERTSPACE', default=False))
 
     def ConvertCase(self, upper=False):
         """Converts the case of the selected text to either all lower
@@ -597,14 +635,15 @@ class EditraStc(ed_basestc.EditraBaseStc):
         cmd_down = evt.CmdDown()
 
         if self.key_handler.PreProcessKey(k_code, ctrl_down,
-                                          cmd_down, shift_down, alt_down):
+                                          cmd_down, shift_down,
+                                          alt_down):
             return
 
-        if wx.Platform == '__WXMAC__' and \
-           self._MacHandleKey(k_code, shift_down, alt_down, ctrl_down, cmd_down):
+        if wx.Platform == '__WXMAC__' and self._MacHandleKey(k_code, shift_down,
+                                                             alt_down, ctrl_down,
+                                                             cmd_down):
             pass
         elif k_code == wx.WXK_RETURN:
-
             if self._config['autoindent'] and not self.AutoCompActive():
                 if self.GetSelectedText():
                     self.CmdKeyExecute(wx.stc.STC_CMD_NEWLINE)
@@ -837,6 +876,43 @@ class EditraStc(ed_basestc.EditraBaseStc):
                            context=self.GetTopLevelParent().GetId())
         evt.Skip()
 
+    def OnDwellStart(self, evt):
+        """Callback hook for mouse dwell start"""
+        position = evt.Position
+        if not self._dwellsent and position >= 0:
+            dwellword = self.GetWordFromPosition(position)[0]
+            line_num = self.LineFromPosition(position) + 1
+            mdata = dict(stc=self, pos=position,
+                         line=line_num,
+                         word=dwellword)
+            ed_msg.PostMessage(ed_msg.EDMSG_UI_STC_DWELL_START, mdata)
+
+            tip = mdata.get('rdata', None)
+            if tip:
+                self.CallTipShow(position, tip)
+            else:
+                # Clients did not need to make use of the calltip
+                # so check if auto-completion provider has anything to display.
+                if not self.IsComment(position) and not self.IsString(position):
+                    endpos = self.WordEndPosition(position, True)
+                    col = self.GetColumn(endpos)
+                    line = self.GetLine(line_num-1)
+                    command = self.GetCommandStr(line, col)
+                    tip = self._code['compsvc'].GetCallTip(command)
+                    if len(tip):
+                        tip_pos = position - (len(dwellword.split('.')[-1]) + 1)
+                        fail_safe = position - self.GetColumn(position)
+                        self.CallTipShow(max(tip_pos, fail_safe), tip)
+        evt.Skip()
+
+    def OnDwellEnd(self, evt):
+        """Callback hook for mouse dwell end"""
+        self._dwellsent = False
+        ed_msg.PostMessage(ed_msg.EDMSG_UI_STC_DWELL_END)
+        if self.CallTipActive():
+            self.CallTipCancel()
+        evt.Skip()
+
     def OnMarginClick(self, evt):
         """Open and Close Folders as Needed
         @param evt: event that called this handler
@@ -874,9 +950,9 @@ class EditraStc(ed_basestc.EditraBaseStc):
             # Bookmarks ect...
             line_clicked = self.LineFromPosition(evt.GetPosition())
             if self.MarkerGet(line_clicked):
-                self.MarkerDelete(line_clicked, ed_basestc.MARK_MARGIN)
+                self.RemoveBookmark(line_clicked)
             else:
-                self.MarkerAdd(line_clicked, ed_basestc.MARK_MARGIN)
+                self.AddBookmark(line_clicked)
 
     def FoldAll(self):
         """Fold Tree In or Out
@@ -1215,7 +1291,9 @@ class EditraStc(ed_basestc.EditraBaseStc):
         @return: bool
 
         """
-        return self._loading is not None
+        # NOTE: keep the getattr check here some cases
+        #       are reporting a yet unexplainable AttributeError here
+        return getattr(self, '_loading', None) is not None
 
     def IsRecording(self):
         """Returns whether the control is in the middle of recording
@@ -1534,6 +1612,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
             lineNum = self.GetCurrentLine()
         super(EditraStc, self).ToggleFold(lineNum)
 
+    @jumpaction
     def WordLeft(self): # pylint: disable-msg=W0221
         """Move caret to beginning of previous word
         @note: override builtin to include extra characters in word
@@ -1558,6 +1637,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
             super(EditraStc, self).WordLeftExtend()
         self.SetWordChars('')
 
+    @jumpaction
     def WordPartLeft(self): # pylint: disable-msg=W0221
         """Move the caret left to the next change in capitalization/punctuation
         @note: overrides default function to not count whitespace as words
@@ -1579,6 +1659,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
         if self.GetTextRange(cpos, cpos + 1) in SPACECHARS:
             super(EditraStc, self).WordPartLeftExtend()
 
+    @jumpaction
     def WordPartRight(self): # pylint: disable-msg=W0221
         """Move the caret to the start of the next word part to the right
         @note: overrides default function to exclude white space
@@ -1589,6 +1670,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
         if self.GetTextRange(cpos, cpos + 1) in SPACECHARS:
             super(EditraStc, self).WordPartRight()
 
+    @jumpaction
     def WordPartRightEnd(self): # pylint: disable-msg=W0221
         """Move caret to end of next change in capitalization/punctuation
         @postcondition: caret is moved
@@ -1622,6 +1704,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
         if self.GetTextRange(cpos, cpos + 1) in SPACECHARS:
             super(EditraStc, self).WordPartRightExtend()
 
+    @jumpaction
     def WordRight(self): # pylint: disable-msg=W0221
         """Move caret to beginning of next word
         @note: override builtin to include extra characters in word
@@ -1634,6 +1717,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
             super(EditraStc, self).WordRight()
         self.SetWordChars('')
 
+    @jumpaction
     def WordRightEnd(self): # pylint: disable-msg=W0221
         """Move caret to end of next change in word
         @note: override builtin to include extra characters in word
@@ -1672,8 +1756,8 @@ class EditraStc(ed_basestc.EditraBaseStc):
         else:
             ed_msg.PostMessage(ed_msg.EDMSG_FILE_OPENING, path)
             self.file.SetPath(path)
-            self.file.ReadAsync(self)
             self._loading = wx.BusyCursor()
+            self.file.ReadAsync(self)
             return True
 
     def ReloadFile(self):
@@ -1693,7 +1777,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
                 self.SetText(self.File.Read())
                 self.SetModTime(ebmlib.GetFileModTime(cfile))
                 for mark in marks:
-                    self.MarkerAdd(mark, ed_basestc.MARK_MARGIN)
+                    self.AddBookmark(mark)
                 self.EndUndoAction()
                 self.SetSavePoint()
             except (AttributeError, OSError, IOError), msg:
