@@ -20,8 +20,8 @@ U{http://editra.org/?page=docs&doc=ess_spec}.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_style.py 65733 2010-10-02 22:45:51Z CJP $"
-__revision__ = "$Revision: 65733 $"
+__svnid__ = "$Id: ed_style.py 66291 2010-11-29 02:15:21Z CJP $"
+__revision__ = "$Revision: 66291 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -74,7 +74,7 @@ class StyleItem(object):
             - ex            = bold underline italic eol
 
         """
-        object.__init__(self)
+        super(StyleItem, self).__init__()
 
         # Workaround for issue of using a list as a default parameter
         # was retaining values from previous calls for some yet to
@@ -353,7 +353,7 @@ class StyleMgr(object):
     modifying styles during run time.
 
     """
-    STYLES         = dict()         # Cache for loaded style set(s)
+    STYLES         = dict()         # Static cache for loaded style set(s)
     FONT_PRIMARY   = u"primary"
     FONT_SECONDARY = u"secondary"
     FONT_SIZE      = u"size"
@@ -365,7 +365,7 @@ class StyleMgr(object):
         @keyword custom: path to custom style sheet to use
 
         """
-        object.__init__(self)
+        super(StyleMgr, self).__init__()
 
         # Attributes
         self.fonts = self.GetFontDictionary()
@@ -643,8 +643,9 @@ class StyleMgr(object):
         elif style_sheet not in StyleMgr.STYLES:
             self.LOG("[ed_style][warn] Style sheet %s does not exists" % style_sheet)
             # Reset to default style
-            Profile_Set('SYNTHEME', 'default')
-            self.SetStyles('default', DEF_STYLE_DICT)
+            if Profile_Get('SYNTHEME') != 'default':
+                Profile_Set('SYNTHEME', 'default')
+                self.SetStyles('default', DEF_STYLE_DICT)
             return False
         else:
             self.LOG("[ed_style][info] Using cached style data")
