@@ -12,8 +12,8 @@ Text/Unicode handling functions and File wrapper class
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_txt.py 62147 2009-09-26 15:40:14Z CJP $"
-__revision__ = "$Revision: 62147 $"
+__svnid__ = "$Id: ed_txt.py 65714 2010-10-01 19:15:39Z CJP $"
+__revision__ = "$Revision: 65714 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -45,7 +45,8 @@ except (LookupError, TypeError):
 
 # File Helper Functions
 BOM = { 'utf-8' : codecs.BOM_UTF8,
-        'utf-16' : codecs.BOM }
+        'utf-16' : codecs.BOM,
+        'utf-32' : codecs.BOM_UTF32 }
 
 # Regex for extracting magic comments from source files
 # i.e *-* coding: utf-8 *-*, encoding=utf-8, ect...
@@ -84,22 +85,24 @@ class EdFile(ebmlib.FileObjectImpl):
         @keyword modtime: file modification time
 
         """
-        ebmlib.FileObjectImpl.__init__(self, path, modtime)
+        super(EdFile, self).__init__(path, modtime)
 
-        # Attribtues
+        # Attributes
         self._magic = dict(comment=None, bad=False)
         self.encoding = None
         self.bom = None
         self._mcallback = list()
         self.__buffer = None
         self._raw = False           # Raw bytes?
+        self._fuzzy_enc = False
 
     def _HandleRawBytes(self, bytes):
-        """Handle preping raw bytes for return to the buffer
+        """Handle prepping raw bytes for return to the buffer
         @param bytes: raw read bytes
         @return: string
 
         """
+        Log("[ed_txt][info] HandleRawBytes called")
         if self._magic['comment']:
             self._magic['bad'] = True
         # Return the raw bytes to put into the buffer
@@ -107,6 +110,7 @@ class EdFile(ebmlib.FileObjectImpl):
         return '\0'.join(bytes)+'\0'
 
     def _ResetBuffer(self):
+        Log("[ed_txt][info] Resetting buffer")
         if self.__buffer is not None:
             del self.__buffer
         self.__buffer = StringIO()
@@ -132,6 +136,7 @@ class EdFile(ebmlib.FileObjectImpl):
         fileobj.SetEncoding(self.encoding)
         fileobj.bom = self.bom
         fileobj._magic = dict(self._magic)
+        fileobj._fuzzy_enc = self._fuzzy_enc
         for cback in self._mcallback:
             fileobj.AddModifiedCallback(cback)
         return fileobj
@@ -147,19 +152,39 @@ class EdFile(ebmlib.FileObjectImpl):
         bytes = self.__buffer.getvalue()
         ustr = u""
         try:
-            if not EdFile._Checker.IsBinaryBytes(bytes):
+            if not self._fuzzy_enc or not EdFile._Checker.IsBinaryBytes(bytes):
                 if self.bom is not None:
                     Log("[ed_txt][info] Stripping %s BOM from text" % self.encoding)
                     bytes = bytes.replace(self.bom, '', 1)
 
+                Log("[ed_txt][info] Attempting to decode with: %s" % self.encoding)
                 ustr = bytes.decode(self.encoding)
+                # TODO: temporary...maybe
+                # Check for utf-16 encodings which use double bytes
+                # can result in NULLs in the string if decoded with
+                # other encodings.
+                if not self.encoding.startswith('utf') and '\0' in ustr:
+                    Log("[ed_txt][info] NULL terminators found in decoded str")
+                    Log("[ed_txt][info] Attempting UTF-16 detection...")
+                    for utf_encoding in ('utf_16_le', 'utf_16_be'):
+                        try:
+                            tmpstr = bytes.decode(utf_encoding)
+                        except UnicodeDecodeError:
+                            pass
+                        else:
+                            self.encoding = utf_encoding
+                            ustr = tmpstr
+                            Log("[ed_txt][info] %s detected" % utf_encoding)
+                            break
+                    else:
+                        Log("[ed_txt][info] No valid UTF-16 bytes detected")
             else:
                 # Binary data was read
                 Log("[ed_txt][info] Binary bytes where read")
                 ustr = self._HandleRawBytes(bytes)
-        except UnicodeDecodeError, msg:
+        except (UnicodeDecodeError, LookupError), msg:
             Log("[ed_txt][err] Error while reading with %s" % self.encoding)
-            Log("[ed_txt][err] %s" % unicode(msg))
+            Log("[ed_txt][err] %s" % msg)
             self.SetLastError(unicode(msg))
             self.Close()
             # Decoding failed so convert to raw bytes for display
@@ -176,6 +201,7 @@ class EdFile(ebmlib.FileObjectImpl):
         #       for besides NUL?
         if not self._raw and '\0' in ustr:
             # Return the raw bytes to put into the buffer
+            Log("[ed_txt][info] DecodeText - joining nul terminators")
             ustr = '\0'.join(bytes)+'\0'
             self._raw = True
 
@@ -183,8 +209,10 @@ class EdFile(ebmlib.FileObjectImpl):
             # TODO: wx/Scintilla Bug?
             # Replace \x05 with a space as it causes the buffer
             # to crash when its inserted.
+            Log("[ed_txt][info] DecodeText - raw - set encoding to binary")
             ustr = ustr.replace('\x05', ' ')
             self.SetEncoding('binary')
+            self._raw = True
 
         return ustr
 
@@ -210,6 +238,7 @@ class EdFile(ebmlib.FileObjectImpl):
 
             # If no byte-order mark check for an encoding comment
             if enc is None:
+                Log("[ed_txt][info] DetectEncoding - Check magic comment")
                 self.bom = None
                 if not self._magic['bad']:
                     enc = CheckMagicComment(lines)
@@ -219,10 +248,16 @@ class EdFile(ebmlib.FileObjectImpl):
                 Log("[ed_txt][info] File Has %s BOM" % enc)
                 self.bom = BOM.get(enc, None)
 
-        if enc is not None:
-            self.encoding = enc
-        else:
-            self.encoding = Profile_Get('ENCODING', default=DEFAULT_ENCODING)
+        if enc is None:
+            Log("[ed_txt][info] Doing brute force encoding check")
+            enc = GuessEncoding(self.GetPath(), 4096)
+
+        if enc is None:
+            self._fuzzy_enc = True
+            enc = Profile_Get('ENCODING', default=DEFAULT_ENCODING)
+
+        Log("[ed_txt][info] DetectEncoding - Set Encoding to %s" % enc)
+        self.encoding = enc 
 
     @property
     def Encoding(self):
@@ -251,7 +286,7 @@ class EdFile(ebmlib.FileObjectImpl):
                 self.encoding = enc
             except UnicodeEncodeError, msg:
                 Log("[ed_txt][err] Failed to encode text with %s" % self.encoding)
-                Log("[ed_txt][err] %s" % str(msg))
+                Log("[ed_txt][err] %s" % msg)
                 self.SetLastError(unicode(msg))
             else:
                 break
@@ -329,13 +364,18 @@ class EdFile(ebmlib.FileObjectImpl):
             if self.encoding is None:
                 # fall back to user setting
                 self.encoding = Profile_Get('ENCODING', default=DEFAULT_ENCODING)
+                Log(("[ed_txt][warn] Failed to detect encoding "
+                    "falling back to default: %s") % self.encoding)
 
             self._ResetBuffer()
+            self._raw = False
 
+            Log("[ed_txt][info] Read - Start reading")
             tmp = self.Handle.read(chunk)
             while len(tmp):
                 self.__buffer.write(tmp)
                 tmp = self.Handle.read(chunk)
+            Log("[ed_txt][info] Read - End reading")
 
             self.Close()
             txt = self.DecodeText()
@@ -343,6 +383,7 @@ class EdFile(ebmlib.FileObjectImpl):
             self._ResetBuffer()
             return txt
         else:
+            Log("[ed_txt][err] Read Error: %s" % self.GetLastError())
             raise ReadError, self.GetLastError()
 
     def ReadAsync(self, control):
@@ -350,6 +391,7 @@ class EdFile(ebmlib.FileObjectImpl):
         @param control: text control to send text to
 
         """
+        Log("[ed_txt][info] EdFile.ReadAsync()")
         pid = control.GetTopLevelParent().GetId()
         filesize = ebmlib.GetFileSize(self.GetPath())
         ed_msg.PostMessage(ed_msg.EDMSG_PROGRESS_STATE, (pid, 1, filesize))
@@ -382,6 +424,7 @@ class EdFile(ebmlib.FileObjectImpl):
                 self.Close()
                 if self._magic['comment']:
                     self._magic['bad'] = True
+            else:
 
                 # TODO: handle incremental mode for 
 #                enc, txt = FallbackReader(self.path)
@@ -389,8 +432,8 @@ class EdFile(ebmlib.FileObjectImpl):
 #                    self.encoding = enc
 #                else:
 #                    raise UnicodeDecodeError, msg
-            Log("[ed_txt][info] Decoded %s with %s" % (self.GetPath(), self.encoding))
-            self.SetModTime(ebmlib.GetFileModTime(self.GetPath()))
+                Log("[ed_txt][info] Decoded %s with %s" % (self.GetPath(), self.encoding))
+                self.SetModTime(ebmlib.GetFileModTime(self.GetPath()))
         else:
             raise ReadError, self.GetLastError()
 
@@ -436,6 +479,7 @@ class EdFile(ebmlib.FileObjectImpl):
         # Check if a magic comment was added or changed
         self._ResetBuffer()
         self.__buffer.write(value)
+        self.__buffer.seek(0)
         enc = CheckMagicComment([ self.__buffer.readline() for x in range(2) ])
         self.__buffer.seek(0)
 
@@ -560,6 +604,7 @@ def CheckBom(line):
     @return: encoding or None
 
     """
+    Log("[ed_txt][info] CheckBom called")
     has_bom = None
     for enc, bom in BOM.iteritems():
         if line.startswith(bom):
@@ -574,6 +619,7 @@ def CheckMagicComment(lines):
     @return: encoding or None
 
     """
+    Log("[ed_txt][info] CheckMagicComment: %s" % str(lines))
     enc = None
     for line in lines:
         match = RE_MAGIC_COMMENT.search(line)
@@ -652,6 +698,26 @@ def FallbackReader(fname):
 
     return (None, None)
 
+def GuessEncoding(fname, sample):
+    """Attempt to guess an encoding
+    @param fname: filename
+    @param sample: pre-read amount
+    @return: encoding or None
+
+    """
+    for enc in GetEncodings():
+        try:
+            handle = open(fname, 'rb')
+            reader = codecs.getreader(enc)(handle)
+            txt = reader.read(sample)
+            reader.close()
+        except Exception, msg:
+            handle.close()
+            continue
+        else:
+            return enc
+    return None
+
 def GetEncodings():
     """Get a list of possible encodings to try from the locale information
     @return: list of strings
