@@ -15,8 +15,8 @@ Provides a dialog for downloading, installing and configuring plugins or Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: plugdlg.py 63588 2010-02-28 16:33:16Z CJP $"
-__revision__ = "$Revision: 63588 $"
+__cvsid__ = "$Id: plugdlg.py 66110 2010-11-10 22:27:34Z CJP $"
+__revision__ = "$Revision: 66110 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -101,8 +101,8 @@ class PluginDialog(wx.Frame):
 
     """
     def __init__(self, parent, id=wx.ID_ANY, title=u'', size=wx.DefaultSize):
-        wx.Frame.__init__(self, parent, title=title, size=size,
-                              style=wx.DEFAULT_FRAME_STYLE)
+        super(PluginDialog, self).__init__(parent, title=title, size=size,
+                                           style=wx.DEFAULT_FRAME_STYLE)
         util.SetWindowIcon(self)
 
         # Attributes
