@@ -16,8 +16,8 @@ and setting of the program by setting values in the Profile.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: prefdlg.py 65770 2010-10-05 14:52:16Z CJP $"
-__revision__ = "$Revision: 65770 $"
+__svnid__ = "$Id: prefdlg.py 66335 2010-12-05 21:58:53Z CJP $"
+__revision__ = "$Revision: 66335 $"
 
 #----------------------------------------------------------------------------#
 # Dependancies
@@ -1083,9 +1083,10 @@ class DocSyntaxPanel(wx.Panel):
         # Syntax Settings
         syn_cb = wx.CheckBox(self, ed_glob.ID_SYNTAX, _("Syntax Highlighting"))
         syn_cb.SetValue(Profile_Get('SYNTAX'))
+        ss_lst = util.GetResourceFiles(u'styles', get_all=True)
+        ss_lst = [sheet for sheet in ss_lst if not sheet.startswith('.')]
         syntheme = ExChoice(self, ed_glob.ID_PREF_SYNTHEME,
-                            choices=util.GetResourceFiles(u'styles',
-                                                          get_all=True),
+                            choices=sorted(ss_lst),
                             default=Profile_Get('SYNTHEME', 'str'))
         line = wx.StaticLine(self, size=(-1, 2))
         lsizer = wx.BoxSizer(wx.VERTICAL)
