@@ -20,8 +20,8 @@ happen during run time.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: profiler.py 63435 2010-02-09 02:34:25Z CJP $"
-__revision__ = "$Revision: 63435 $"
+__svnid__ = "$Id: profiler.py 65751 2010-10-03 21:24:06Z CJP $"
+__revision__ = "$Revision: 65751 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -105,6 +105,7 @@ _DEFAULTS = {
            'TOOLBAR'    : True,             # Show Toolbar
            'USETABS'    : False,            # Use tabs instead of spaces
            'USE_PROXY'  : False,            # Use Proxy server settings?
+           'VIEWVERTSPACE' : False,         # Allow extra virtual space in buffer
            'VI_EMU'     : False,            # Use Vi emulation mode
            'VI_NORMAL_DEFAULT' : False,     # Use Normal mode by default
            'WARN_EOL'   : True,             # Warn about mixed eol characters
@@ -482,6 +483,10 @@ def UpdateProfileLoader():
                                  os.path.basename(prof_name))
         Profile_Set('MYPROFILE', prof_name)
 
+    # Use just the relative profile name for local(portable) config paths
+    if CONFIG['ISLOCAL']:
+        prof_name = os.path.basename(prof_name)
+
     writer.write(prof_name)
     writer.write(u"\nVERSION\t" + VERSION)
     writer.close()
