@@ -17,8 +17,8 @@ editor can load to configure the styles of the text.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: style_editor.py 64596 2010-06-16 00:45:12Z CJP $"
-__revision__ = "$Revision: 64596 $"
+__svnid__ = "$Id: style_editor.py 66335 2010-12-05 21:58:53Z CJP $"
+__revision__ = "$Revision: 66335 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -66,7 +66,7 @@ class StyleEditor(wx.Dialog):
         @todo: rework the layout
 
         """
-        wx.Dialog.__init__(self, parent, id_, title, style=style)
+        super(StyleEditor, self).__init__(parent, id_, title, style=style)
 
         # Attributes
         self.LOG = wx.GetApp().GetLog()
@@ -165,6 +165,7 @@ class StyleEditor(wx.Dialog):
         ss_lbl = wx.StaticText(self.ctrl_pane, wx.ID_ANY,
                                _("Style Theme") + u": ")
         ss_lst = util.GetResourceFiles(u'styles', get_all=True)
+        ss_lst = [sheet for sheet in ss_lst if not sheet.startswith('.')]
         ss_choice = wx.Choice(self.ctrl_pane, ed_glob.ID_PREF_SYNTHEME,
                               choices=sorted(ss_lst))
         ss_choice.SetToolTipString(_("Base new theme on existing one"))
@@ -275,7 +276,9 @@ class StyleEditor(wx.Dialog):
             else:
                 # Update Style Sheet Control
                 sheet = u".".join(os.path.basename(sheet_path).split(u'.')[:-1])
-                ss_c.SetItems(util.GetResourceFiles(u'styles', get_all=True))
+                ss_lst = util.GetResourceFiles(u'styles', get_all=True)
+                ss_lst = [sheet for sheet in ss_lst if not sheet.startswith('.')]
+                ss_c.SetItems(sorted(ss_lst))
                 ss_c.SetStringSelection(sheet)
                 ss_c.Enable()
                 self.FindWindowById(wx.ID_NEW).SetValue(False)
@@ -561,7 +564,7 @@ class SettingsPanel(wx.Panel):
     """
     def __init__(self, parent):
         """Create the settings panel"""
-        wx.Panel.__init__(self, parent)
+        super(SettingsPanel, self).__init__(parent)
 
         # Layout
         self.__DoLayout()
@@ -663,7 +666,7 @@ class SettingsPanel(wx.Panel):
 class PreviewPanel(eclib.ControlBox):
     """Panel to hold the preview window and selector"""
     def __init__(self, parent):
-        eclib.ControlBox.__init__(self, parent)
+        super(PreviewPanel, self).__init__(parent)
 
         # Attributes
         self.LOG = wx.GetApp().GetLog()
@@ -671,6 +674,8 @@ class PreviewPanel(eclib.ControlBox):
                                                 style=wx.SUNKEN_BORDER)
 
         # Setup
+        self.preview.SetEdgeColumn(80)
+        self.preview.SetEdgeMode(wx.stc.STC_EDGE_LINE)
         self.preview.SetCaretLineVisible(True)
         self.__DoLayout()
 
