@@ -21,8 +21,8 @@ LANGUAGE: Python
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: synextreg.py 65461 2010-09-02 04:09:42Z CJP $"
-__revision__ = "$Revision: 65461 $"
+__svnid__ = "$Id: synextreg.py 66046 2010-11-06 03:12:18Z CJP $"
+__revision__ = "$Revision: 66046 $"
 
 #-----------------------------------------------------------------------------#
 import os
@@ -358,7 +358,7 @@ EXT_MAP = {
            'matlab'             : LANG_MATLAB,
            'mssql'              : LANG_MSSQL,
            'nasm'               : LANG_NASM,
-           'ctl'                : LANG_NONMEM,
+           'ctl nonmem'         : LANG_NONMEM,
            'nsi nsh'            : LANG_NSIS,
            'mm m'               : LANG_OBJC,
            'oct octave'         : LANG_OCTAVE,
