@@ -18,12 +18,13 @@ provides a higher level interface into the L{UpdateService}.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: updater.py 57682 2008-12-31 02:21:20Z CJP $"
-__revision__ = "$Revision: 57682 $"
+__svnid__ = "$Id: updater.py 66214 2010-11-19 22:43:00Z CJP $"
+__revision__ = "$Revision: 66214 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
 import os
+import sys
 import stat
 import re
 import urllib2
@@ -36,6 +37,7 @@ import ed_glob
 import ed_event
 from profiler import CalcVersionValue, Profile_Get
 import util
+import ebmlib
 
 #--------------------------------------------------------------------------#
 # Globals
@@ -47,6 +49,7 @@ DL_LIN = 'SRC'          # This may need to change in future
 DL_MAC = 'Macintosh'
 DL_SRC = 'SRC'
 DL_WIN = 'Windows'
+ISBIN = hasattr(sys, 'frozen')
 
 _ = wx.GetTranslation
 #--------------------------------------------------------------------------#
@@ -99,9 +102,9 @@ class UpdateService(object):
         """
         if wx.Platform == '__WXGTK__':
             dist = DL_LIN
-        elif wx.Platform == '__WXMAC__':
+        elif wx.Platform == '__WXMAC__' and ISBIN:
             dist = DL_MAC
-        elif wx.Platform == '__WXMSW__':
+        elif wx.Platform == '__WXMSW__' and ISBIN:
             dist = DL_WIN
         else:
             dist = DL_SRC
@@ -133,12 +136,13 @@ class UpdateService(object):
         """
         page = self.GetPageText(ed_glob.HOME_PAGE + "/version.php?check=True")
         found = re.findall(RE_VERSION, page)
-        if len(found):
+        if False:#len(found):
             return found[0] # Should be the first/only match found
         else:
             util.Log("[updater][warn] UpdateService.GetCurrentVersionStr "
                      "Failed to get version info.")
-            return _("Unable to retrieve version info")
+            # TODO: GetTranslation is not threadsafe!!!
+            return "Unable to retrieve version info"
 
     def GetFileSize(self, url):
         """Gets the size of a file by address
@@ -195,7 +199,7 @@ class UpdateService(object):
         if CalcVersionValue(ed_glob.VERSION) < CalcVersionValue(current):
             dl_path = self.GetCurrFileURL()
             dl_file = dl_path.split('/')[-1]
-            dl_to = util.GetUniqueName(dl_to, dl_file)
+            dl_to = ebmlib.GetUniqueName(dl_to, dl_file)
             blk_sz = 4096
             read = 0
             try:
@@ -472,7 +476,7 @@ class UpdateProgress(wx.Gauge, UpdateService):
     #--- Protected Member Functions ---#
     def _DownloadThread(self, *args):
         """Processes the download and checks that the file has been downloaded
-        properly. Then returns either True if the download was succesfull or
+        properly. Then returns either True if the download was successful or
         False if it failed in some way.
         @return: success status of download
 
@@ -481,7 +485,7 @@ class UpdateProgress(wx.Gauge, UpdateService):
         return dl_ok
 
     def _ResultNotifier(self, delayedResult):
-        """Recieves the return from the result of the worker thread and
+        """Receives the return from the result of the worker thread and
         notifies the interested party with the result.
         @param delayedResult:  value from worker thread
 
@@ -651,7 +655,7 @@ class DownloadDialog(wx.Frame):
         self._progress.Abort()
         # Wait till thread has halted before exiting
         while self._progress.IsDownloading():
-            wx.Yield()
+            wx.YieldIfNeeded()
         wx.GetApp().UnRegisterWindow(repr(self))
         evt.Skip()
 
