@@ -12,8 +12,8 @@ This file contains various helper functions and utilities that the program uses.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: util.py 63289 2010-01-28 03:10:42Z CJP $"
-__revision__ = "$Revision: 63289 $"
+__svnid__ = "$Id: util.py 65708 2010-10-01 13:06:40Z CJP $"
+__revision__ = "$Revision: 65708 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -48,7 +48,7 @@ class DropTargetFT(wx.PyDropTarget):
         @param window: window to recieve drop objects
 
         """
-        wx.PyDropTarget.__init__(self)
+        super(DropTargetFT, self).__init__()
 
         # Attributes
         self.window = window
@@ -78,13 +78,16 @@ class DropTargetFT(wx.PyDropTarget):
                 longest = ext
 
         cords = [ (0, x * longest[1]) for x in xrange(len(txt)) ]
-        mdc = wx.MemoryDC(wx.EmptyBitmap(longest[0] + 5,
-                                         longest[1] * len(txt), 32))
-        mdc.SetBackgroundMode(wx.TRANSPARENT)
-        mdc.SetTextForeground(stc.GetDefaultForeColour())
-        mdc.SetFont(stc.GetDefaultFont())
-        mdc.DrawTextList(txt, cords)
-        self._tmp = wx.DragImage(mdc.GetAsBitmap())
+        try:
+            mdc = wx.MemoryDC(wx.EmptyBitmap(longest[0] + 5,
+                                             longest[1] * len(txt), 32))
+            mdc.SetBackgroundMode(wx.TRANSPARENT)
+            mdc.SetTextForeground(stc.GetDefaultForeColour())
+            mdc.SetFont(stc.GetDefaultFont())
+            mdc.DrawTextList(txt, cords)
+            self._tmp = wx.DragImage(mdc.GetAsBitmap())
+        except wx.PyAssertionError, msg:
+            Log("[droptargetft][err] %s" % str(msg))
 
     def InitObjects(self):
         """Initializes the text and file data objects
@@ -137,8 +140,8 @@ class DropTargetFT(wx.PyDropTarget):
     def OnDragOver(self, x_cord, y_cord, drag_result):
         """Called when the cursor is moved during a drag action
         @return: result of drag over
-        @todo: For some reason the carrat postion changes which can be seen
-               by the brackets getting highlighted. However the actual carrat
+        @todo: For some reason the caret position changes which can be seen
+               by the brackets getting highlighted. However the actual caret
                is not moved.
 
         """
@@ -149,6 +152,7 @@ class DropTargetFT(wx.PyDropTarget):
                 self.ScrollBuffer(stc, x_cord, y_cord)
             drag_result = wx.DragCopy
         else:
+            # A drag image was created
             if hasattr(stc, 'DoDragOver'):
                 point = wx.Point(x_cord, y_cord)
                 self._tmp.BeginDrag(point - self._lastp, stc)
@@ -190,7 +194,7 @@ class DropTargetFT(wx.PyDropTarget):
             elif len(text) > 0:
                 if self._data['tcallb'] is not None:
                     self._data['tcallb'](text)
-                else:
+                elif hasattr(self.window, 'DoDropText'):
                     self.window.DoDropText(x_cord, y_cord, text)
         self.InitObjects()
         return drag_result
